@@ -19,10 +19,10 @@
  ***************************************************************************/
 #include "revisiontree.h"
 #include "stopdlg.h"
-#include "log_entry.hpp"
-#include "LogCache.hpp"
-#include "ReposLog.hpp"
-#include "url.hpp"
+#include "log_entry.h"
+#include "LogCache.h"
+#include "ReposLog.h"
+#include "url.h"
 #include "sub2qt.h"
 #include "revtreewidget.h"
 #include "revgraphview.h"
