@@ -136,7 +136,7 @@ namespace svn
             const Revision revision = svn::Revision::HEAD,
             bool detailed_remote = false,
             bool hide_externals = false,
-            const StringArray & changelists=StringArray() ) throw (ClientException) = 0;
+            const StringArray & changelists=StringArray() ) = 0;
 
     /**
      * Returns the status of a single file in the path.
@@ -149,7 +149,7 @@ namespace svn
      * @return a Status with Statis.isVersioned = FALSE
      */
     virtual StatusPtr
-    singleStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException)=0;
+    singleStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD)=0;
 
   /**
      * Executes a revision checkout.
@@ -169,7 +169,7 @@ namespace svn
               svn::Depth depth=DepthInfinity,
               bool ignore_externals=false,
               bool overwrite=false
-             ) throw (ClientException) = 0;
+             ) = 0;
 
     /**
      * relocate wc @a from to @a to
@@ -177,7 +177,7 @@ namespace svn
      */
     virtual void
     relocate (const Path & path, const TQString &from_url,
-              const TQString &to_url, bool recurse) throw (ClientException)=0;
+              const TQString &to_url, bool recurse)=0;
 
     /**
      * Sets a single file for deletion.
@@ -186,7 +186,7 @@ namespace svn
     virtual svn::Revision
             remove (const Path & path, bool force,
                     bool keep_local = true,
-                    const PropertiesMap&revProps = PropertiesMap()) throw (ClientException)=0;
+                    const PropertiesMap&revProps = PropertiesMap())=0;
 
     /**
      * Sets files for deletion.
@@ -199,7 +199,7 @@ namespace svn
     remove (const Targets & targets,
             bool force,
             bool keep_local=true,
-            const PropertiesMap&revProps=PropertiesMap()) throw (ClientException) = 0;
+            const PropertiesMap&revProps=PropertiesMap()) = 0;
 
     /**
      * Reverts a couple of files to a pristiner state.
@@ -209,7 +209,7 @@ namespace svn
     revert (const Targets & targets,
             Depth depth,
             const StringArray&changelist=StringArray()
-           ) throw (ClientException)=0;
+           )=0;
 
 
     /**
@@ -222,7 +222,7 @@ namespace svn
      * @exception ClientException
      */
     virtual void
-    add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_parents = true) throw (ClientException)=0;
+    add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_parents = true)=0;
 
     /**
      * Updates the file or directory.
@@ -238,7 +238,7 @@ namespace svn
     virtual Revisions
     update (const Targets & path, const Revision & revision,
             Depth depth,bool ignore_externals,bool allow_unversioned,
-            bool sticky_depth) throw (ClientException) = 0;
+            bool sticky_depth) = 0;
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -252,7 +252,7 @@ namespace svn
     virtual TQByteArray
     cat (const Path & path,
           const Revision & revision,
-          const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException)=0;
+          const Revision & peg_revision=svn_opt_revision_unspecified)=0;
     /**
      * Retrieves the contents for a specific @a revision of
      * a @a path at @a peg_revision
@@ -267,7 +267,7 @@ namespace svn
     cat(svn::stream::SvnStream&buffer,
             const Path & path,
             const Revision & revision,
-            const Revision & peg_revision) throw (ClientException)=0;
+            const Revision & peg_revision)=0;
     /**
      * Retrieves the contents for a specific @a revision of
      * a @a path at @a peg_revision
@@ -282,7 +282,7 @@ namespace svn
     get (const Path & path,
           const TQString  & target,
           const Revision & revision,
-          const Revision & peg_revision=svn_opt_revision_unspecified) throw (ClientException)=0;
+          const Revision & peg_revision=svn_opt_revision_unspecified)=0;
 
     /**
      * Retrieves the contents for a specific @a revision of
@@ -303,7 +303,7 @@ namespace svn
               const DiffOptions&diffoptions = DiffOptions(),
               bool ignore_mimetypes = false,
               bool include_merged_revisions = false
-             ) throw (ClientException)=0;
+             )=0;
 
     /**
      * Commits changes to the repository. This usually requires
@@ -324,7 +324,7 @@ namespace svn
             const svn::StringArray&contents=svn::StringArray(),
             const PropertiesMap&revProps=PropertiesMap(),
             bool keep_changelist=false
-           ) throw (ClientException)=0;
+           )=0;
 
     /**
      * Copies a versioned file with the history preserved.
@@ -333,7 +333,7 @@ namespace svn
     virtual svn::Revision
     copy (const Path & srcPath,
           const Revision & srcRevision,
-          const Path & destPath) throw (ClientException)=0;
+          const Path & destPath)=0;
     /**
      * Copies a versioned file with the history preserved.
      * @since subversion 1.5 api
@@ -345,7 +345,7 @@ namespace svn
             const Revision & srcRevision,
             const Revision & pegRevision,
             const Path & destPath,
-            bool asChild=false,bool makeParent=false,const PropertiesMap&revProps=PropertiesMap()) throw (ClientException)=0;
+            bool asChild=false,bool makeParent=false,const PropertiesMap&revProps=PropertiesMap())=0;
 
     /**
      * Moves or renames a file.
@@ -354,7 +354,7 @@ namespace svn
     virtual svn::Revision
     move (const Path & srcPath,
           const Path & destPath,
-          bool force) throw (ClientException)=0;
+          bool force)=0;
     /**
      * Moves or renames a file.
      * @exception ClientException
@@ -362,7 +362,7 @@ namespace svn
     virtual svn::Revision
             move (const Targets & srcPath,
                   const Path & destPath,
-                  bool force,bool asChild,bool makeParent,const PropertiesMap&revProps=PropertiesMap()) throw (ClientException)=0;
+                  bool force,bool asChild,bool makeParent,const PropertiesMap&revProps=PropertiesMap())=0;
 
     /**
      * Creates a directory directly in a repository or creates a
@@ -381,7 +381,7 @@ namespace svn
            const TQString& message,
            bool makeParent=true,
            const PropertiesMap&revProps=PropertiesMap()
-          ) throw (ClientException)=0;
+          )=0;
     /**
      * Creates a directory directly in a repository or creates a
      * directory on disk and schedules it for addition. If <i>path</i>
@@ -398,7 +398,7 @@ namespace svn
            const TQString& message,
            bool makeParent=true,
            const PropertiesMap&revProps=PropertiesMap()
-          ) throw (ClientException)=0;
+          )=0;
 
     /**
      * Recursively cleans up a local directory, finishing any
@@ -407,13 +407,13 @@ namespace svn
      * @exception ClientException
      */
     virtual void
-    cleanup (const Path & path) throw (ClientException)=0;
+    cleanup (const Path & path)=0;
 
     /**
      * Removes the 'conflicted' state on a file.
      * @exception ClientException
      */
-    virtual void resolve (const Path & path,Depth depth,const ConflictResult&resolution=ConflictResult()) throw (ClientException)=0;
+    virtual void resolve (const Path & path,Depth depth,const ConflictResult&resolution=ConflictResult())=0;
 
     /**
      * Exports the contents of either a subversion repository into a
@@ -439,7 +439,7 @@ namespace svn
               const TQString&native_eol=TQString(),
               bool ignore_externals = false,
               svn::Depth depth=svn::DepthInfinity
-              ) throw (ClientException)=0;
+              )=0;
 
     /**
      * Update local copy to mirror a new url. This excapsulates the
@@ -455,7 +455,7 @@ namespace svn
               bool sticky_depth = true,
               bool ignore_externals=false,
               bool allow_unversioned=false
-             ) throw (ClientException)=0;
+             )=0;
 
     /**
      * Import file or directory PATH into repository directory URL at
@@ -473,7 +473,7 @@ namespace svn
             const TQString& message,
             svn::Depth depth,
             bool no_ignore,bool no_unknown_nodetype,
-            const PropertiesMap&revProps=PropertiesMap()) throw (ClientException)=0;
+            const PropertiesMap&revProps=PropertiesMap())=0;
 
     /**
      * Merge changes from two paths into a new local path.
@@ -488,7 +488,7 @@ namespace svn
            bool dry_run=false,
            bool record_only=false,
            const StringArray&merge_options=StringArray()
-          ) throw (ClientException)=0;
+          )=0;
 
     virtual void
     merge_peg(const Path&src,
@@ -501,7 +501,7 @@ namespace svn
                       bool force=false,
                       bool record_only=false,
                       const StringArray&merge_options=StringArray()
-                     ) throw (ClientException)=0;
+                     )=0;
 
     virtual void
     merge_peg(const Path&src,
@@ -513,7 +513,7 @@ namespace svn
               bool dry_run=false,
               bool force=false,
               const StringArray&merge_options=StringArray()
-             ) throw (ClientException)=0;
+             )=0;
 
     /**
      * Retrieve information for the given path
@@ -531,7 +531,7 @@ namespace svn
           const Revision & rev,
           const Revision & peg_revision=svn_opt_revision_unspecified,
           const StringArray&changelists=StringArray()
-         ) throw (ClientException)=0;
+         )=0;
 
     /**
      * Retrieve log information for the given path
@@ -558,7 +558,7 @@ namespace svn
          bool strictNodeHistory=true,int limit = 0,
          bool include_merged_revisions = false,
          const StringArray&revprops=StringArray()
-        ) throw (ClientException)=0;
+        )=0;
 
     /**
      * Retrieve log information for the given path
@@ -586,7 +586,7 @@ namespace svn
          bool strictNodeHistory=true,int limit = 0,
          bool include_merged_revisions = false,
          const StringArray&revprops=StringArray()
-        ) throw (ClientException)=0;
+        )=0;
 
     /**
      * Produce diff output which describes the delta between
@@ -618,7 +618,7 @@ namespace svn
           bool noDiffDeleted,bool ignore_contenttype,
           const StringArray&extra,
           const StringArray&changelists
-            ) throw (ClientException)=0;
+            )=0;
 
     /**
      * Same as other diff but extra options always set to empty list.
@@ -627,7 +627,7 @@ namespace svn
             diff_peg (const Path & tmpPath, const Path & path,const Path&relativeTo,
                   const Revision & revision1, const Revision & revision2, const Revision& peg_revision,
                   Depth depth, bool ignoreAncestry,
-                  bool noDiffDeleted,bool ignore_contenttype) throw (ClientException)=0;
+                  bool noDiffDeleted,bool ignore_contenttype)=0;
 
     /**
      * Produce diff output which describes the delta between
@@ -660,7 +660,7 @@ namespace svn
           bool noDiffDeleted,bool ignore_contenttype,
           const StringArray&extra,
           const StringArray&changelists
-         ) throw (ClientException)=0;
+         )=0;
 
     /**
      * Same as other diff but extra options and changelists always set to empty list.
@@ -669,7 +669,7 @@ namespace svn
             diff (const Path & tmpPath, const Path & path1,const Path & path2,const Path&relativeTo,
                   const Revision & revision1, const Revision & revision2,
                   Depth depth, bool ignoreAncestry,
-                  bool noDiffDeleted,bool ignore_contenttype) throw (ClientException)=0;
+                  bool noDiffDeleted,bool ignore_contenttype)=0;
 
     /**
      * lists entries in @a pathOrUrl no matter whether local or
@@ -690,7 +690,7 @@ namespace svn
     list (const Path& pathOrUrl,
           const Revision& revision,
           const Revision& peg,
-          svn::Depth depth,bool retrieve_locks) throw (ClientException)=0;
+          svn::Depth depth,bool retrieve_locks)=0;
 
     /**
      * lists properties in @a path no matter whether local or
@@ -840,7 +840,7 @@ namespace svn
    virtual void
    lock (const Targets & targets,
         const TQString& message,
-        bool steal_lock) throw (ClientException)=0;
+        bool steal_lock)=0;
     /**
      * unlock files in repository or working copy
      * @param targets items to unlock
@@ -848,7 +848,7 @@ namespace svn
      */
     virtual void
     unlock (const Targets&targets,
-            bool break_lock) throw (ClientException)=0;
+            bool break_lock)=0;
 
     virtual void
     url2Revision(const TQString&revstring,
