@@ -53,7 +53,7 @@ namespace svn
               svn::Depth depth,
               bool ignore_externals,
               bool overwrite
-                        ) throw (ClientException)
+                        )
   {
     Pool subPool;
     svn_revnum_t revnum = 0;
@@ -90,7 +90,7 @@ namespace svn
 
   Revision Client_impl::remove (const Path & path,bool force,
                             bool keep_local,
-                            const PropertiesMap&revProps) throw (ClientException)
+                            const PropertiesMap&revProps)
   {
       Targets targets (path.path());
       return remove(targets,force,keep_local,revProps);
@@ -101,7 +101,7 @@ namespace svn
                   bool force,
                   bool keep_local,
                   const PropertiesMap&revProps
-                      ) throw (ClientException)
+                      )
   {
     Pool pool;
 
@@ -141,7 +141,7 @@ namespace svn
   Client_impl::revert (const Targets & targets,
                   Depth depth,
                   const StringArray&changelist
-                      ) throw (ClientException)
+                      )
   {
     Pool pool;
 
@@ -169,7 +169,7 @@ namespace svn
 
   void
   Client_impl::add (const Path & path,
-                    svn::Depth depth,bool force, bool no_ignore, bool add_parents) throw (ClientException)
+                    svn::Depth depth,bool force, bool no_ignore, bool add_parents)
   {
     Pool pool;
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
@@ -202,7 +202,7 @@ namespace svn
                   bool ignore_externals,
                   bool allow_unversioned,
                   bool sticky_depth
-                      ) throw (ClientException)
+                      )
   {
     Pool pool;
     Revisions resulting;
@@ -241,7 +241,7 @@ namespace svn
                        svn::Depth depth,bool keep_locks,
                        const svn::StringArray&changelist,
                        const PropertiesMap&revProps,
-                       bool keep_changelist) throw (ClientException)
+                       bool keep_changelist)
   {
     Pool pool;
 
@@ -292,7 +292,7 @@ namespace svn
                     const Path & destPath,
                      bool asChild,bool makeParent,
                      const PropertiesMap&revProps
-                     ) throw (ClientException)
+                     )
     {
         if (srcPaths.size()<1)
         {
@@ -351,7 +351,7 @@ namespace svn
   Revision
   Client_impl::copy (const Path & srcPath,
                 const Revision & srcRevision,
-                const Path & destPath) throw (ClientException)
+                const Path & destPath)
   {
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
       return copy(srcPath,srcRevision,srcRevision,destPath,true,false);
@@ -379,7 +379,7 @@ namespace svn
 
   svn::Revision Client_impl::move (const Path & srcPath,
                 const Path & destPath,
-                bool force) throw (ClientException)
+                bool force)
   {
 
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
@@ -416,7 +416,7 @@ namespace svn
              bool force,
              bool asChild,
              bool makeParent,
-             const PropertiesMap&revProps) throw (ClientException)
+             const PropertiesMap&revProps)
   {
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
       Pool pool;
@@ -467,7 +467,7 @@ namespace svn
                  const TQString& message,
                  bool makeParent,
                  const PropertiesMap&revProps
-                     ) throw (ClientException)
+                     )
   {
     Targets targets(path.path());
     return mkdir(targets,message,makeParent,revProps);
@@ -478,7 +478,7 @@ namespace svn
                  const TQString&msg,
                  bool makeParent,
                  const PropertiesMap&revProps
-                     ) throw (ClientException)
+                     )
   {
     Pool pool;
     m_context->setLogMessage(msg);
@@ -515,7 +515,7 @@ namespace svn
   }
 
   void
-  Client_impl::cleanup (const Path & path) throw (ClientException)
+  Client_impl::cleanup (const Path & path)
   {
     Pool subPool;
     apr_pool_t * apr_pool = subPool.pool ();
@@ -527,7 +527,7 @@ namespace svn
       throw ClientException (error);
   }
 
-  void Client_impl::resolve(const Path & path,Depth depth,const ConflictResult&resolution) throw (ClientException)
+  void Client_impl::resolve(const Path & path,Depth depth,const ConflictResult&resolution)
   {
     Pool pool;
 #if ((SVN_VER_MAJOR == 1) && (SVN_VER_MINOR >= 5)) || (SVN_VER_MAJOR > 1)
@@ -556,7 +556,7 @@ namespace svn
               bool overwrite,
               const TQString&native_eol,
               bool ignore_externals,
-              svn::Depth depth) throw (ClientException)
+              svn::Depth depth)
   {
     Pool pool;
     svn_revnum_t revnum = 0;
@@ -608,7 +608,7 @@ namespace svn
                          bool sticky_depth,
                          bool ignore_externals,
                          bool allow_unversioned
-                        ) throw (ClientException)
+                        )
   {
     Pool pool;
     svn_revnum_t revnum = 0;
@@ -655,7 +655,7 @@ namespace svn
                   svn::Depth depth,
                   bool no_ignore,bool no_unknown_nodetype,
                   const PropertiesMap&revProps
-                      ) throw (ClientException)
+                      )
 
   {
     svn_commit_info_t *commit_info = NULL;
@@ -698,7 +698,7 @@ namespace svn
   Client_impl::relocate (const Path & path,
                     const TQString& from_url,
                     const TQString& to_url,
-                    bool recurse) throw (ClientException)
+                    bool recurse)
   {
     Pool pool;
     svn_error_t * error =
