@@ -398,7 +398,7 @@ namespace svn
                   const Revision revision,
                   bool detailed_remote,
                   const bool hide_externals,
-                  const StringArray & changelists) throw (ClientException)
+                  const StringArray & changelists)
   {
     if (Url::isValid (path.path())) {
         return remoteStatus (this, path, depth, get_all, update,
@@ -483,7 +483,7 @@ namespace svn
   }
 
   StatusPtr
-  Client_impl::singleStatus (const Path& path,bool update,const Revision revision) throw (ClientException)
+  Client_impl::singleStatus (const Path& path,bool update,const Revision revision)
   {
     if (Url::isValid (path.path()))
       return remoteSingleStatus (this, path,revision, m_context);
@@ -500,7 +500,7 @@ namespace svn
        bool strictNodeHistory,int limit,
        bool include_merged_revisions,
        const StringArray&revprops
-                   ) throw (ClientException)
+                   )
   {
     Targets target(path);
     Pool pool;
@@ -573,7 +573,7 @@ namespace svn
                     bool strictNodeHistory,int limit,
                     bool include_merged_revisions,
                     const StringArray&revprops
-                   ) throw (ClientException)
+                   )
   {
     Targets target(path);
     Pool pool;
@@ -647,7 +647,7 @@ namespace svn
                 const Revision & rev,
                 const Revision & peg_revision,
                 const StringArray&changelists
-                    ) throw (ClientException)
+                    )
   {
 
     InfoEntries ientries;
