@@ -21,12 +21,12 @@
 #include "tdeiosvn.h"
 #include "tdeiolistener.h"
 
-#include "svnqttypes.hpp"
-#include "dirent.hpp"
-#include "url.hpp"
-#include "status.hpp"
-#include "targets.hpp"
-#include "info_entry.hpp"
+#include "svnqttypes.h"
+#include "dirent.h"
+#include "url.h"
+#include "status.h"
+#include "targets.h"
+#include "info_entry.h"
 #include "tdesvnsettings.h"
 #include "sub2qt.h"
 #include "sshagent.h"
